package Bundle::Business::Shipping;

$VERSION = '1.11';

1;

__END__

=head1 NAME

Bundle::Business::Shipping - a Bundle for Business::Shipping.

=head1 SYNOPSIS

 perl -MCPAN -e install Bundle::Business::Shipping

See the INSTALL file in Business::Shipping for more information.

=head1 CONTENTS

Business::Shipping

Business::Shipping::DataFiles

Cache::FileCache

Class::MethodMaker::Engine

Clone

Config::IniFiles

Crypt::SSLeay

Log::Log4perl

LWP::UserAgent

Scalar::Util

XML::DOM

XML::Simple         2.05

=head1 AUTHOR

Dan Browning E<lt>F<db@kavod.com>E<gt>, Kavod Technologies, L<http://www.kavod.com>.

=head1 COPYRIGHT AND LICENCE

Copyright (c) 2003-2004 Kavod Technologies and Daniel Browning. All rights 
reserved.  This program is free software; you may redistribute it and/or modify
it under the same terms as Perl itself. See LICENSE for more info.

=cut
